=== modified file 'lib/lp/bugs/browser/bugtarget.py'
--- lib/lp/bugs/browser/bugtarget.py	2011-04-19 15:10:57 +0000
+++ lib/lp/bugs/browser/bugtarget.py	2011-04-20 12:59:55 +0000
@@ -553,6 +553,8 @@
             # We're being called from the generic bug filing form, so
             # manually set the chosen distribution as the context.
             context = distribution
+        elif IProjectGroup.providedBy(context):
+            context = data['product']
         elif IMaloneApplication.providedBy(context):
             context = data['bugtarget']
 

=== modified file 'lib/lp/bugs/browser/tests/test_bugtarget_filebug.py'
--- lib/lp/bugs/browser/tests/test_bugtarget_filebug.py	2011-02-10 20:01:17 +0000
+++ lib/lp/bugs/browser/tests/test_bugtarget_filebug.py	2011-04-20 12:59:55 +0000
@@ -10,7 +10,10 @@
     )
 
 from canonical.launchpad.ftests import login
-from canonical.launchpad.testing.pages import find_tag_by_id
+from canonical.launchpad.testing.pages import (
+    find_main_content,
+    find_tag_by_id,
+    )
 from canonical.launchpad.webapp.servers import LaunchpadTestRequest
 from canonical.testing.layers import DatabaseFunctionalLayer
 from lp.bugs.browser.bugtarget import (
@@ -280,8 +283,16 @@
             product, name='+filebug', principal=user)
         html = view.render()
         self.assertIsNot(None, find_tag_by_id(html, 'filebug-search-form'))
-        # The main bug filing form is not shown.
-        self.assertIs(None, find_tag_by_id(html, 'filebug-form'))
+        # The main bug filing form is rendered but hidden inside an invisible
+        # filebug-container.
+        main_content = find_main_content(html)
+        filebug_form = main_content.find(id='filebug-form')
+        self.assertIsNot(None, filebug_form)
+        filebug_form_container = filebug_form.findParents(
+            id='filebug-form-container')[0]
+        style_attrs = [item.strip()
+                       for item in filebug_form_container['style'].split(";")]
+        self.assertTrue('display: none' in style_attrs)
 
     def test_bug_filing_view_with_dupe_search_disabled(self):
         # When a user files a bug for a product where searching for

=== modified file 'lib/lp/bugs/stories/guided-filebug/xx-bug-reporting-guidelines.txt'
--- lib/lp/bugs/stories/guided-filebug/xx-bug-reporting-guidelines.txt	2011-02-01 23:50:13 +0000
+++ lib/lp/bugs/stories/guided-filebug/xx-bug-reporting-guidelines.txt	2011-04-20 12:59:55 +0000
@@ -42,6 +42,16 @@
     ...     print extract_text(find_tags_by_class(
     ...         user_browser.contents, 'informational message')[0])
 
+    >>> def print_visible_guidelines(context_path, guidelines):
+    ...     result = guidelines.findParents(id='filebug-form-container')
+    ...     style_attrs = []
+    ...     if result:
+    ...         filebug_form_container = result[0]
+    ...         style_attrs = [item.strip()
+    ...             for item in filebug_form_container['style'].split(";")]
+    ...     if (result and not 'display: none' in style_attrs):
+    ...         print 'Found %s guidelines: %s' % (context_path, guidelines)
+
     >>> for context_name, context_path, view in contexts:
     ...     filebug_url = (
     ...         'http://launchpad.dev/%s/+filebug' % (context_path,))
@@ -49,7 +59,7 @@
     ...     guidelines = find_tag_by_id(
     ...         user_browser.contents, 'bug-reporting-guidelines')
     ...     if guidelines is not None:
-    ...         print 'Found %s guidelines: %s' % (context_path, guidelines)
+    ...         print_visible_guidelines(context_path, guidelines)
 
 But they are displayed once you've got to the step of entering a bug
 description.
@@ -58,7 +68,8 @@
     ...     filebug_url = (
     ...         'http://launchpad.dev/%s/+filebug' % (context_path,))
     ...     user_browser.open(filebug_url)
-    ...     user_browser.getControl('Summary').value = "It doesn't work"
+    ...     user_browser.getControl('Summary', index=0).value = (
+    ...         "It doesn't work")
     ...     user_browser.getControl('Continue').click()
     ...     user_browser.getControl('Further information').value = (
     ...         'please help!')
@@ -111,7 +122,7 @@
 
     >>> user_browser.open(
     ...     'http://launchpad.dev/ubuntu/warty/+filebug')
-    >>> user_browser.getControl('Summary').value = "It doesn't work"
+    >>> user_browser.getControl('Summary', index=0).value = "It doesn't work"
     >>> user_browser.getControl('Continue').click()
     >>> print extract_text(find_tag_by_id(
     ...     user_browser.contents, 'bug-reporting-guidelines'))
@@ -149,7 +160,7 @@
 
     >>> user_browser.open(
     ...     'http://launchpad.dev/ubuntu/+filebug')
-    >>> user_browser.getControl('Summary').value = "It doesn't work"
+    >>> user_browser.getControl('Summary', index=0).value = "It doesn't work"
     >>> user_browser.getControl('Continue').click()
     >>> print extract_text(find_tag_by_id(
     ...     user_browser.contents, 'bug-reporting-guidelines'))

=== modified file 'lib/lp/bugs/stories/guided-filebug/xx-bug-reporting-tools.txt'
--- lib/lp/bugs/stories/guided-filebug/xx-bug-reporting-tools.txt	2010-02-23 15:10:04 +0000
+++ lib/lp/bugs/stories/guided-filebug/xx-bug-reporting-tools.txt	2011-04-20 12:59:55 +0000
@@ -93,9 +93,9 @@
 After the user fills in the summary and click on the button, we'll still
 be on the same URL, with the token present.
 
-    >>> user_browser.getControl('Summary').value
+    >>> user_browser.getControl('Summary', index=0).value
     ''
-    >>> user_browser.getControl('Summary').value = 'A new bug'
+    >>> user_browser.getControl('Summary', index=0).value = 'A new bug'
     >>> user_browser.getControl('Continue').click()
     >>> user_browser.url == filebug_url
     True
@@ -167,14 +167,14 @@
     ...    'http://launchpad.dev/ubuntu/+source/mozilla-firefox/+filebug/'
     ...     '%s' % blob_token)
 
-    >>> user_browser.getControl('Summary').value
+    >>> user_browser.getControl('Summary', index=0).value
     'Initial bug summary'
 
 The user can of course change the summary if he wants to.
 
-    >>> user_browser.getControl('Summary').value = 'Another summary'
+    >>> user_browser.getControl('Summary', index=0).value = 'Another summary'
     >>> user_browser.getControl('Continue').click()
-    >>> user_browser.getControl('Summary').value
+    >>> user_browser.getControl('Summary', index=0).value
     'Another summary'
 
 === Tags ===
@@ -194,7 +194,7 @@
     >>> user_browser.open(
     ...    'http://launchpad.dev/ubuntu/+source/mozilla-firefox/'
     ...     '+filebug/%s' % blob_token)
-    >>> user_browser.getControl('Summary').value = 'Another summary'
+    >>> user_browser.getControl('Summary', index=0).value = 'Another summary'
     >>> user_browser.getControl('Continue').click()
 
     >>> user_browser.getControl('Tags').value
@@ -203,7 +203,7 @@
 The user can of course change the tags if he wants.
 
     >>> user_browser.getControl('Tags').value = 'bar baz'
-    >>> user_browser.getControl('Summary').value = 'Bug Summary'
+    >>> user_browser.getControl('Summary', index=0).value = 'Bug Summary'
     >>> user_browser.getControl('Further information').value = (
     ...     'Bug description.')
     >>> user_browser.getControl('Submit Bug Report').click()
@@ -220,7 +220,7 @@
     >>> user_browser.open(
     ...    'http://launchpad.dev/ubuntu/+source/mozilla-firefox/+filebug/'
     ...     '%s' % blob_token)
-    >>> user_browser.getControl('Summary').value = 'Bug Summary'
+    >>> user_browser.getControl('Summary', index=0).value = 'Bug Summary'
     >>> user_browser.getControl('Continue').click()
 
     >>> user_browser.getControl('Further information').value = (
@@ -264,7 +264,7 @@
     ...    'http://launchpad.dev/ubuntu/+source/mozilla-firefox/+filebug/'
     ...     '%s' % blob_token)
     >>> user_browser.open(filebug_url)
-    >>> user_browser.getControl('Summary').value = 'Another summary'
+    >>> user_browser.getControl('Summary', index=0).value = 'Another summary'
     >>> user_browser.getControl('Continue').click()
     >>> user_browser.getControl('Further information').value = (
     ...     'A bug description.')

=== modified file 'lib/lp/bugs/templates/bugtarget-filebug-search.pt'
--- lib/lp/bugs/templates/bugtarget-filebug-search.pt	2011-04-19 14:11:24 +0000
+++ lib/lp/bugs/templates/bugtarget-filebug-search.pt	2011-04-20 12:59:55 +0000
@@ -125,7 +125,8 @@
 
         <div id="possible-duplicates" style="text-align: left;">
         </div>
-        <div id="filebug-form-container" class="transparent" style="opacity: 0; display: none">
+        <div tal:condition="context/enable_bugfiling_duplicate_search"
+             id="filebug-form-container" class="transparent" style="opacity: 0; display: none">
           <tal:filebug-form define="launchpad_form_id string:filebug-form">
             <metal:display-similar-bugs
                 use-macro="context/@@+filebug-macros/inline-filebug-form" />

=== modified file 'lib/lp/bugs/templates/bugtarget-macros-filebug.pt'
--- lib/lp/bugs/templates/bugtarget-macros-filebug.pt	2011-04-19 15:10:32 +0000
+++ lib/lp/bugs/templates/bugtarget-macros-filebug.pt	2011-04-20 12:59:55 +0000
@@ -44,6 +44,13 @@
     </td>
   </tr>
 
+  <noscript>
+    <tal:product tal:define="widget nocall:view/widgets/product|nothing"
+                 tal:condition="widget">
+      <metal:widget use-macro="context/@@launchpad_form/widget_row" />
+    </tal:product>
+  </noscript>
+
   <metal:summary tal:define="widget nocall:view/widgets/title">
     <metal:row use-macro="context/@@launchpad_form/widget_row" />
   </metal:summary>

